@@ -466,7 +466,21 @@ class FakePathModule:
         """Return the argument with an initial component of ~ or ~user
         replaced by that user's home directory.
         """
-        path = self._os_path.expanduser(path)
+        if (
+            self.filesystem.is_windows_fs != (os.name == "nt")
+            and matching_string(path, "~") == path[:1]
+        ):
+            home = self._os_path.expanduser("~")
+            username = self._os_path.split(home)[1]
+            if self.filesystem.is_windows_fs:
+                home = self._os_path.join("C:", "Users", username)
+            else:
+                sep = matching_string(path, self.sep)
+                home = sep + self._os_path.join("home", username)
+            _, _, rest = path.partition(matching_string(path, self.sep))
+            path = self._os_path.join(home, *rest)
+        else:
+            path = self._os_path.expanduser(path)
         return path.replace(
             matching_string(path, self._os_path.sep),
             matching_string(path, self.sep),
